AI Policy
=========

This section contains documentation about how AI assistants and agents
should interact with this project's codebase.

.. toctree::
   :maxdepth: 2

   AI_POLICY.md
   AI_GUIDELINES.md
   AI_ACKNOWLEDGEMENT.md
   audit/AI_AUDIT_FILE.md
   audit/AI_AUDIT_PROCESS.md
   audit/AI_AUDIT_PROCESS_REVIEW.md
